@@ -18,7 +18,7 @@ def kill_processes_bind_to_port(port):
         os.kill(int(data[1]), signal.SIGKILL)
 
 
-def visualsim():
+def run():
     ports = [2222, 1900, 1099]
     [kill_processes_bind_to_port(_) for _ in ports]
     os.system("cd VS_LM && sh StartServer.sh & cd VS_AR && sh VisualSim.sh")
